@@ -1,5 +1,5 @@
-#ifndef __8MRL122_16_LEN2_200
-#define __8MRL122_16_LEN2_200
+#ifndef __8MRL80_6_LEN2_050
+#define __8MRL80_6_LEN2_050
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MRL122_16_LEN2_200_BUILDER_VERSION_MAJOR  0
-#define 8MRL122_16_LEN2_200_BUILDER_VERSION_MINOR  9
-#define 8MRL122_16_LEN2_200_BUILDER_VERSION_BUGFIX 16
-#define 8MRL122_16_LEN2_200_BUILDER_VERSION_SUFFIX ""
-#define 8MRL122_16_LEN2_200_BUILDER_VERSION        "0.9.16"
+#define 8MRL80_6_LEN2_050_BUILDER_VERSION_MAJOR  0
+#define 8MRL80_6_LEN2_050_BUILDER_VERSION_MINOR  9
+#define 8MRL80_6_LEN2_050_BUILDER_VERSION_BUGFIX 16
+#define 8MRL80_6_LEN2_050_BUILDER_VERSION_SUFFIX ""
+#define 8MRL80_6_LEN2_050_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
+static inline result_t set_profile_8MRL80_6_LEn2_050(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -31,7 +31,7 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   feedback_settings.IPS = 0;
   feedback_settings.FeedbackType = FEEDBACK_ENCODER;
   feedback_settings.FeedbackFlags = FEEDBACK_ENC_TYPE_DIFFERENTIAL | FEEDBACK_ENC_TYPE_AUTO;
-  feedback_settings.CountsPerTurn = 500000;
+  feedback_settings.CountsPerTurn = 2880000;
   result = set_feedback_settings(id, &feedback_settings);
 
   if (result != result_ok)
@@ -44,13 +44,13 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   home_settings_t home_settings;
   memset((void*)&home_settings, 0, sizeof(home_settings_t));
-  home_settings.FastHome = 100;
+  home_settings.FastHome = 10;
   home_settings.uFastHome = 0;
   home_settings.SlowHome = 50;
   home_settings.uSlowHome = 0;
   home_settings.HomeDelta = 0;
   home_settings.uHomeDelta = 0;
-  home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_REV | HOME_DIR_SECOND;
+  home_settings.HomeFlags = HOME_STOP_SECOND_REV | HOME_STOP_FIRST_REV | HOME_DIR_SECOND;
   result = set_home_settings(id, &home_settings);
 
   if (result != result_ok)
@@ -63,11 +63,11 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   move_settings_t move_settings;
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
-  move_settings.Speed = 120;
+  move_settings.Speed = 20;
   move_settings.uSpeed = 0;
-  move_settings.Accel = 9;
-  move_settings.Decel = 9;
-  move_settings.AntiplaySpeed = 500;
+  move_settings.Accel = 250;
+  move_settings.Decel = 250;
+  move_settings.AntiplaySpeed = 120;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -87,9 +87,9 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   engine_settings.NomSpeed = 240;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON;
-  engine_settings.Antiplay = -10304;
+  engine_settings.Antiplay = -7680;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
-  engine_settings.StepsPerRev = 20;
+  engine_settings.StepsPerRev = 8;
   result = set_engine_settings(id, &engine_settings);
 
   if (result != result_ok)
@@ -155,9 +155,9 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = 0;
   edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW;
-  edges_settings.LeftBorder = 12500;
+  edges_settings.LeftBorder = 72000;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 487500;
+  edges_settings.RightBorder = 2808000;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -174,9 +174,9 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   pid_settings.KpU = 0;
   pid_settings.KiU = 0;
   pid_settings.KdU = 0;
-  pid_settings.Kpf = 25;
-  pid_settings.Kif = 0.014999999664723873;
-  pid_settings.Kdf = 0.25;
+  pid_settings.Kpf = 300;
+  pid_settings.Kif = 0.07999999821186066;
+  pid_settings.Kdf = 0.800000011920929;
   result = set_pid_settings(id, &pid_settings);
 
   if (result != result_ok)
@@ -255,8 +255,8 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   control_settings_t control_settings;
   memset((void*)&control_settings, 0, sizeof(control_settings_t));
-  control_settings.MaxSpeed[0] = 50;
-  control_settings.MaxSpeed[1] = 500;
+  control_settings.MaxSpeed[0] = 2;
+  control_settings.MaxSpeed[1] = 20;
   control_settings.MaxSpeed[2] = 0;
   control_settings.MaxSpeed[3] = 0;
   control_settings.MaxSpeed[4] = 0;
@@ -449,9 +449,9 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   motor_information_t motor_information;
   memset((void*)&motor_information, 0, sizeof(motor_information_t));
-  const int8_t motor_information_Manufacturer_temp[16] = {0, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80};
+  const int8_t motor_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(motor_information.Manufacturer, motor_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t motor_information_PartNumber_temp[24] = {0, 67, 45, 105, 45, 52, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t motor_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(motor_information.PartNumber, motor_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_motor_information(id, &motor_information);
 
@@ -465,7 +465,7 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   motor_settings_t motor_settings;
   memset((void*)&motor_settings, 0, sizeof(motor_settings_t));
-  motor_settings.MotorType = MOTOR_TYPE_STEP | MOTOR_TYPE_UNKNOWN;
+  motor_settings.MotorType = MOTOR_TYPE_UNKNOWN;
   motor_settings.ReservedField = 0;
   motor_settings.Poles = 0;
   motor_settings.Phases = 0;
@@ -483,7 +483,7 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   motor_settings.SpeedConstant = 0;
   motor_settings.SpeedTorqueGradient = 0;
   motor_settings.MechanicalTimeConstant = 0;
-  motor_settings.MaxSpeed = 1866;
+  motor_settings.MaxSpeed = 0;
   motor_settings.MaxCurrent = 0;
   motor_settings.MaxCurrentTime = 0;
   motor_settings.NoLoadCurrent = 0;
@@ -500,9 +500,9 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   encoder_information_t encoder_information;
   memset((void*)&encoder_information, 0, sizeof(encoder_information_t));
-  const int8_t encoder_information_Manufacturer_temp[16] = {0, 97, 120, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t encoder_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(encoder_information.Manufacturer, encoder_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t encoder_information_PartNumber_temp[24] = {0, 54, 45, 69, 65, 83, 89, 45, 49, 48, 50, 52, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t encoder_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(encoder_information.PartNumber, encoder_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_encoder_information(id, &encoder_information);
 
@@ -520,7 +520,7 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   encoder_settings.SupplyVoltageMin = 0;
   encoder_settings.SupplyVoltageMax = 0;
   encoder_settings.MaxCurrentConsumption = 0;
-  encoder_settings.PPR = 5000;
+  encoder_settings.PPR = 0;
   encoder_settings.EncoderSettings = 0;
   result = set_encoder_settings(id, &encoder_settings);
 
@@ -583,10 +583,10 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
 
   gear_settings_t gear_settings;
   memset((void*)&gear_settings, 0, sizeof(gear_settings_t));
-  gear_settings.ReductionIn = 1;
-  gear_settings.ReductionOut = 1;
+  gear_settings.ReductionIn = 0;
+  gear_settings.ReductionOut = 0;
   gear_settings.RatedInputTorque = 0;
-  gear_settings.RatedInputSpeed = 1500;
+  gear_settings.RatedInputSpeed = 0;
   gear_settings.MaxOutputBacklash = 0;
   gear_settings.InputInertia = 0;
   gear_settings.Efficiency = 0;
@@ -613,7 +613,7 @@ static inline result_t set_profile_8MRL122_16_LEn2_200(device_t id)
   accessories_settings.TSMin = 0;
   accessories_settings.TSMax = 0;
   accessories_settings.TSGrad = 0;
-  accessories_settings.TSSettings = TS_TYPE_THERMOCOUPLE | TS_TYPE_UNKNOWN;
+  accessories_settings.TSSettings = TS_TYPE_UNKNOWN;
   accessories_settings.LimitSwitchesSettings = 0;
   result = set_accessories_settings(id, &accessories_settings);
 
