@@ -1,5 +1,5 @@
-#ifndef __8MVT45_13_1
-#define __8MVT45_13_1
+#ifndef __8MVT70_13_1
+#define __8MVT70_13_1
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MVT45_13_1_BUILDER_VERSION_MAJOR  0
-#define 8MVT45_13_1_BUILDER_VERSION_MINOR  9
-#define 8MVT45_13_1_BUILDER_VERSION_BUGFIX 16
-#define 8MVT45_13_1_BUILDER_VERSION_SUFFIX ""
-#define 8MVT45_13_1_BUILDER_VERSION        "0.9.16"
+#define 8MVT70_13_1_BUILDER_VERSION_MAJOR  0
+#define 8MVT70_13_1_BUILDER_VERSION_MINOR  9
+#define 8MVT70_13_1_BUILDER_VERSION_BUGFIX 16
+#define 8MVT70_13_1_BUILDER_VERSION_SUFFIX ""
+#define 8MVT70_13_1_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MVT45_13_1(device_t id)
+static inline result_t set_profile_8MVT70_13_1(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -66,7 +66,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   move_settings.Speed = 1000;
   move_settings.uSpeed = 0;
   move_settings.Accel = 2000;
-  move_settings.Decel = 5000;
+  move_settings.Decel = 4000;
   move_settings.AntiplaySpeed = 1000;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
@@ -83,11 +83,11 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
   engine_settings.NomVoltage = 1;
-  engine_settings.NomCurrent = 600;
-  engine_settings.NomSpeed = 2000;
+  engine_settings.NomCurrent = 1200;
+  engine_settings.NomSpeed = 4000;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON | ENGINE_REVERSE;
-  engine_settings.Antiplay = 550;
+  engine_settings.Antiplay = 575;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
   engine_settings.StepsPerRev = 200;
   result = set_engine_settings(id, &engine_settings);
@@ -154,7 +154,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   edges_settings_t edges_settings;
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = BORDER_STOP_RIGHT | BORDER_STOP_LEFT;
-  edges_settings.EnderFlags = ENDER_SWAP;
+  edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
   edges_settings.LeftBorder = -435;
   edges_settings.uLeftBorder = 0;
   edges_settings.RightBorder = 2035;
@@ -413,7 +413,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
   const int8_t stage_information_Manufacturer_temp[16] = {0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 86, 84, 52, 53, 45, 49, 51, 45, 49, 0, 83, 83, 52, 51, 0, 53, 48, 0, 0, 0, 0, 83};
+  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 86, 84, 55, 48, 45, 49, 51, 45, 49, 0, 83, 83, 52, 51, 0, 53, 48, 0, 0, 0, 0, 83};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -430,7 +430,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   stage_settings.LeadScrewPitch = 1;
   const int8_t stage_settings_Units_temp[8] = {0, 109, 0, 114, 101, 101, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
-  stage_settings.MaxSpeed = 10;
+  stage_settings.MaxSpeed = 20;
   stage_settings.TravelRange = 13;
   stage_settings.SupplyVoltageMin = 0;
   stage_settings.SupplyVoltageMax = 0;
@@ -483,7 +483,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   motor_settings.SpeedConstant = 0;
   motor_settings.SpeedTorqueGradient = 0;
   motor_settings.MechanicalTimeConstant = 0;
-  motor_settings.MaxSpeed = 2400;
+  motor_settings.MaxSpeed = 5000;
   motor_settings.MaxCurrent = 0;
   motor_settings.MaxCurrentTime = 0;
   motor_settings.NoLoadCurrent = 0;
@@ -586,7 +586,7 @@ static inline result_t set_profile_8MVT45_13_1(device_t id)
   gear_settings.ReductionIn = 1;
   gear_settings.ReductionOut = 1;
   gear_settings.RatedInputTorque = 0;
-  gear_settings.RatedInputSpeed = 1500;
+  gear_settings.RatedInputSpeed = 0;
   gear_settings.MaxOutputBacklash = 0;
   gear_settings.InputInertia = 0;
   gear_settings.Efficiency = 0;
