@@ -1,4 +1,4 @@
-def set_profile_8MT295X_740_5(lib, id):
+def set_profile_8MT295X_340_25(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -56,11 +56,11 @@ def set_profile_8MT295X_740_5(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 800
+    move_settings.Speed = 1000
     move_settings.uSpeed = 0
     move_settings.Accel = 2000
     move_settings.Decel = 4000
-    move_settings.AntiplaySpeed = 800
+    move_settings.AntiplaySpeed = 1000
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -75,7 +75,7 @@ def set_profile_8MT295X_740_5(lib, id):
 
     engine_settings.NomVoltage = 1
     engine_settings.NomCurrent = 2100
-    engine_settings.NomSpeed = 1600
+    engine_settings.NomSpeed = 3200
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -87,7 +87,7 @@ def set_profile_8MT295X_740_5(lib, id):
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
     engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 400
+    engine_settings.Antiplay = 575
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -182,9 +182,9 @@ def set_profile_8MT295X_740_5(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = 240
+    edges_settings.LeftBorder = 180
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 28360
+    edges_settings.RightBorder = 26020
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -290,8 +290,8 @@ def set_profile_8MT295X_740_5(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 80
-    control_settings.MaxSpeed[1] = 800
+    control_settings.MaxSpeed[0] = 100
+    control_settings.MaxSpeed[1] = 1000
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
@@ -446,7 +446,7 @@ def set_profile_8MT295X_740_5(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 84, 50, 57, 53, 88, 45, 55, 52, 48, 45, 53, 0, 53, 0, 68, 67, 0, 0, 0, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 84, 50, 57, 53, 88, 45, 51, 52, 48, 45, 50, 46, 53, 0, 68, 67, 0, 0, 0, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -455,10 +455,10 @@ def set_profile_8MT295X_740_5(lib, id):
 
     stage_settings = stage_settings_t()
 
-    stage_settings.LeadScrewPitch = 5
+    stage_settings.LeadScrewPitch = 2.5
     stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
     stage_settings.MaxSpeed = 40
-    stage_settings.TravelRange = 740
+    stage_settings.TravelRange = 340
     stage_settings.SupplyVoltageMin = 0
     stage_settings.SupplyVoltageMax = 0
     stage_settings.MaxCurrentConsumption = 0
