@@ -1,4 +1,4 @@
-def set_profile_8MTL1401_300_LEn1_25(lib, id):
+def set_profile_8MTL220_600_LEn1_50(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -18,7 +18,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
         FEEDBACK_ENC_REVERSE = 1
         FEEDBACK_ENC_TYPE_AUTO = 0
     feedback_settings.FeedbackFlags = FeedbackFlags_.FEEDBACK_ENC_TYPE_DIFFERENTIAL | FeedbackFlags_.FEEDBACK_ENC_REVERSE | FeedbackFlags_.FEEDBACK_ENC_TYPE_AUTO
-    feedback_settings.CountsPerTurn = 1200000
+    feedback_settings.CountsPerTurn = 600000
     result = lib.set_feedback_settings(id, byref(feedback_settings))
 
     if result != Result.Ok:
@@ -27,9 +27,9 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
 
     home_settings = home_settings_t()
 
-    home_settings.FastHome = 26
+    home_settings.FastHome = 52
     home_settings.uFastHome = 0
-    home_settings.SlowHome = 8
+    home_settings.SlowHome = 15
     home_settings.uSlowHome = 0
     home_settings.HomeDelta = -10000
     home_settings.uHomeDelta = 0
@@ -56,11 +56,11 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 50
+    move_settings.Speed = 100
     move_settings.uSpeed = 0
-    move_settings.Accel = 2000
-    move_settings.Decel = 2000
-    move_settings.AntiplaySpeed = 50
+    move_settings.Accel = 4000
+    move_settings.Decel = 4000
+    move_settings.AntiplaySpeed = 100
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -74,8 +74,8 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
     engine_settings = engine_settings_t()
 
     engine_settings.NomVoltage = 1200
-    engine_settings.NomCurrent = 2200
-    engine_settings.NomSpeed = 100
+    engine_settings.NomCurrent = 1300
+    engine_settings.NomSpeed = 200
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -87,7 +87,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
     engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_LIMIT_CURR | EngineFlags_.ENGINE_ACCEL_ON
-    engine_settings.Antiplay = 8392
+    engine_settings.Antiplay = 13392
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -181,7 +181,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
         ENDER_SW2_ACTIVE_LOW = 4
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
-    edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
+    edges_settings.EnderFlags = EnderFlags_.ENDER_SWAP
     edges_settings.LeftBorder = -5700000
     edges_settings.uLeftBorder = 0
     edges_settings.RightBorder = 5700000
@@ -290,7 +290,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 50
+    control_settings.MaxSpeed[0] = 100
     control_settings.MaxSpeed[1] = 0
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
@@ -446,7 +446,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 84, 76, 49, 52, 48, 49, 45, 51, 48, 48, 45, 76, 69, 110, 49, 45, 50, 53, 0, 0, 0, 83])
+    stage_information.PartNumber = bytes([56, 77, 84, 76, 50, 50, 48, 45, 54, 48, 48, 45, 76, 69, 110, 49, 45, 53, 48, 0, 0, 0, 0, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -458,7 +458,7 @@ def set_profile_8MTL1401_300_LEn1_25(lib, id):
     stage_settings.LeadScrewPitch = 30
     stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
     stage_settings.MaxSpeed = 400
-    stage_settings.TravelRange = 300
+    stage_settings.TravelRange = 600
     stage_settings.SupplyVoltageMin = 0
     stage_settings.SupplyVoltageMax = 0
     stage_settings.MaxCurrentConsumption = 0
