@@ -16,7 +16,7 @@ namespace ximc
 
 	public static class Version
 	{
-		public const String version = "2.14.27";
+		public const String version = "2.14.30";
 	};
 
 /*
@@ -163,6 +163,7 @@ namespace ximc
 		public const uint FEEDBACK_ENCODER_MEDIATED    = 0x06;
 
 		public const uint FEEDBACK_ENC_REVERSE              = 0x01;
+		public const uint FEEDBACK_ENC_ADAPTIVE_HOLDING     = 0x02;
 		public const uint FEEDBACK_ENC_TYPE_BITS            = 0xC0;
 		public const uint FEEDBACK_ENC_TYPE_AUTO            = 0x00;
 		public const uint FEEDBACK_ENC_TYPE_SINGLE_ENDED    = 0x40;
@@ -732,8 +733,8 @@ namespace ximc
 		public uint Temp_ADC;
 		public uint Joy_ADC;
 		public uint Pot_ADC;
-		public uint L5_ADC;
-		public uint H5_ADC;
+		public uint Enc_Check_ADC;
+		public uint deprecated0;
 		public int A1Voltage;
 		public int A2Voltage;
 		public int B1Voltage;
@@ -745,9 +746,9 @@ namespace ximc
 		public int Temp;
 		public int Joy;
 		public int Pot;
-		public int L5;
-		public int H5;
-		public uint deprecated;
+		public int Enc_Check;
+		[MarshalAs(UnmanagedType.ByValArray, SizeConst = 2)]
+		public uint[] deprecated1;
 		public int R;
 		public int L;
 	};
